==> edc_auth-0.1.39-py3-none-any.whl: edc_auth/models/user_profile.py <==
from django.contrib.auth.models import User, Group
from django.contrib.sites.models import Site
from django.core.validators import RegexValidator
from django.db import models
from django.db.models.deletion import CASCADE
from django.utils.safestring import mark_safe
from django.utils.translation import gettext_lazy as _
from edc_notification.model_mixins import NotificationUserProfileModelMixin

from ..constants import CUSTOM_ROLE
from ..group_names import EVERYONE
from .role import Role
from edc_auth.constants import STAFF_ROLE
import pdb


class UserProfile(NotificationUserProfileModelMixin, models.Model):

    user = models.OneToOneField(User, on_delete=CASCADE)

    sites = models.ManyToManyField(Site, blank=True)

    job_title = models.CharField(max_length=100, null=True, blank=True)

    alternate_email = models.EmailField(
        _("Alternate email address"), blank=True, null=True
    )

    mobile = models.CharField(
        max_length=25,
        validators=[RegexValidator(regex="^\+\d+")],
        null=True,
        blank=True,
        help_text="e.g. +1234567890",
    )

    clinic_label_printer = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        help_text=mark_safe(
            f'Change in <a href="/edc_label/">Edc Label Administration</a>'
        ),
    )

    lab_label_printer = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        help_text=mark_safe(
            f'Change in <a href="/edc_label/">Edc Label Administration</a>'
        ),
    )

    print_server = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        help_text=mark_safe(
            f'Change in <a href="/edc_label/">Edc Label Administration</a>'
        ),
    )

    roles = models.ManyToManyField(Role, blank=True)

    def __str__(self):
        return self.user.username

    def add_groups_for_roles(self):
        """Add groups to this user for the selected roles.

        Called by m2m signal.
        """
        if CUSTOM_ROLE not in [obj.name for obj in self.roles.all()]:
            group_names = [group.name for group in self.user.groups.all()]
            add_group_names = []
            for role in self.roles.all():
                for group in role.groups.all():
                    if group.name not in group_names:
                        add_group_names.append(group.name)
            add_group_names = list(set(add_group_names))
            for name in add_group_names:
                self.user.groups.add(Group.objects.get(name=name))
                self.user.save()

    def remove_groups_for_roles(self, pk_set):
        """Remove groups from this user for the removed roles.

        Called by m2m signal.
        """
        if CUSTOM_ROLE in [obj.name for obj in Role.objects.filter(pk__in=pk_set)]:
            self.user.groups.clear()
            self.user.userprofile.roles.clear()
            self.user.userprofile.roles.add(Role.objects.get(name=STAFF_ROLE))
        else:
            remove_group_names = []
            current_group_names = []
            for role in self.roles.all():
                current_group_names.extend([group.name for group in role.groups.all()])
            for role in Role.objects.filter(pk__in=pk_set):
                remove_group_names.extend(
                    [
                        group.name
                        for group in role.groups.all()
                        if group.name not in current_group_names
                    ]
                )
            for name in remove_group_names:
                self.user.groups.remove(Group.objects.get(name=name))

==> edc_auth-0.1.43-py3-none-any.whl: edc_auth/models/user_profile.py <==
from django.contrib.auth.models import User, Group
from django.contrib.sites.models import Site
from django.core.validators import RegexValidator
from django.db import models
from django.db.models.deletion import CASCADE
from django.utils.safestring import mark_safe
from django.utils.translation import gettext_lazy as _
from edc_notification.model_mixins import NotificationUserProfileModelMixin

from ..constants import CUSTOM_ROLE, STAFF_ROLE
from .role import Role


class UserProfile(NotificationUserProfileModelMixin, models.Model):

    user = models.OneToOneField(User, on_delete=CASCADE)

    sites = models.ManyToManyField(Site, blank=True)

    job_title = models.CharField(max_length=100, null=True, blank=True)

    alternate_email = models.EmailField(
        _("Alternate email address"), blank=True, null=True
    )

    mobile = models.CharField(
        max_length=25,
        validators=[RegexValidator(regex="^\+\d+")],
        null=True,
        blank=True,
        help_text="e.g. +1234567890",
    )

    clinic_label_printer = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        help_text=mark_safe(
            f'Change in <a href="/edc_label/">Edc Label Administration</a>'
        ),
    )

    lab_label_printer = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        help_text=mark_safe(
            f'Change in <a href="/edc_label/">Edc Label Administration</a>'
        ),
    )

    print_server = models.CharField(
        max_length=100,
        null=True,
        blank=True,
        help_text=mark_safe(
            f'Change in <a href="/edc_label/">Edc Label Administration</a>'
        ),
    )

    roles = models.ManyToManyField(Role, blank=True)

    def __str__(self):
        return self.user.username

    def add_groups_for_roles(self, pk_set):
        """Add groups to this user for the selected roles.

        Called by m2m signal.
        """
        if CUSTOM_ROLE not in [obj.name for obj in self.roles.all()]:
            group_names = [group.name for group in self.user.groups.all()]
            add_group_names = []
            for role in self.roles.all():
                for group in role.groups.all():
                    if group.name not in group_names:
                        add_group_names.append(group.name)
            add_group_names = list(set(add_group_names))
            for name in add_group_names:
                self.user.groups.add(Group.objects.get(name=name))
                self.user.save()

    def remove_groups_for_roles(self, pk_set):
        """Remove groups from this user for the removed roles.

        Called by m2m signal.
        """
        if CUSTOM_ROLE in [obj.name for obj in Role.objects.filter(pk__in=pk_set)]:
            self.user.groups.clear()
            self.user.userprofile.roles.clear()
            self.user.userprofile.roles.add(Role.objects.get(name=STAFF_ROLE))
        else:
            remove_group_names = []
            current_group_names = []
            for role in self.roles.all():
                current_group_names.extend(
                    [group.name for group in role.groups.all()])
            for role in Role.objects.filter(pk__in=pk_set):
                remove_group_names.extend(
                    [
                        group.name
                        for group in role.groups.all()
                        if group.name not in current_group_names
                    ]
                )
            for name in remove_group_names:
                self.user.groups.remove(Group.objects.get(name=name))
